@@ -1,8 +1,7 @@
 #!/usr/bin/env python
-# -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2017 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
 # This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
@@ -21,10 +20,11 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-from __future__ import print_function
-import gammu
+
 import sys
 
+import gammu
+
 
 def main():
     state_machine = gammu.StateMachine()
@@ -32,14 +32,14 @@ def main():
     state_machine.Init()
 
     if len(sys.argv) != 2:
-        print('This requires one parameter with memory type!')
+        print("This requires one parameter with memory type!")
         sys.exit(1)
 
     memory_type = sys.argv[1]
 
     status = state_machine.GetMemoryStatus(Type=memory_type)
 
-    remain = status['Used']
+    remain = status["Used"]
 
     start = True
 
@@ -49,15 +49,15 @@ def main():
             start = False
         else:
             entry = state_machine.GetNextMemory(
-                Location=entry['Location'], Type=memory_type
+                Location=entry["Location"], Type=memory_type
             )
         remain = remain - 1
 
         print()
-        print('{0:<15}: {1:d}'.format('Location', entry['Location']))
-        for v in entry['Entries']:
-            print('{0:<15}: {1}'.format(v['Type'], str(v['Value'])))
+        print("{:<15}: {:d}".format("Location", entry["Location"]))
+        for v in entry["Entries"]:
+            print("{:<15}: {}".format(v["Type"], str(v["Value"])))
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
